==> hyades.source_1.0.3_20030929_1406.zip: org/eclipse/hyades/test/http/internal/junit/editor/HttpEditorExtension.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.http.internal.junit.editor;

import org.eclipse.hyades.test.common.internal.editor.TestSuiteEditorExtension;
import org.eclipse.hyades.test.http.TestHttpPlugin;
import org.eclipse.hyades.test.ui.internal.editor.form.util.WidgetFactory;
import org.eclipse.hyades.ui.editor.IHyadesEditorPart;

/**
 * @author marcelop
 * @since 1.0.2
 */
public class HttpEditorExtension 
extends TestSuiteEditorExtension
{
	public static final String EXTENSION_ID = "org.eclipse.hyades.test.http.internal.junit.editor.HttpEditorExtension";

	/**
	 * @see org.eclipse.hyades.ui.editor.IEditorExtension#createPages()
	 */
	public void createPages()
	{
		IHyadesEditorPart hyadesEditorPart = getHyadesEditorPart();
		WidgetFactory widgetFactory = new WidgetFactory();
		
		setTestSuiteForm(new HttpForm(this, widgetFactory));
		getTestSuiteForm().setTestCasePageIndex(PAGE_TEST_CASES);
		hyadesEditorPart.addPage(getTestSuiteForm().createControl());
		hyadesEditorPart.setPageText(PAGE_OVERVIEW, TestHttpPlugin.getString("W_OVERVIEW"));

		setTestCasesForm(new HttpTestCasesForm(this, widgetFactory));
		hyadesEditorPart.addPage(getTestCasesForm().createControl());
		hyadesEditorPart.setPageText(PAGE_TEST_CASES, TestHttpPlugin.getString("W_REQUESTS"));
		
		setBehaviorForm(new HttpBehaviorForm(this, widgetFactory));
		hyadesEditorPart.addPage(getBehaviorForm().createControl());
		hyadesEditorPart.setPageText(PAGE_BEHAVIOR, TestHttpPlugin.getString("W_BEHAVIOR"));
		
		getTestSuiteForm().updateTitle();
	}
}

==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/test/http/internal/junit/editor/HttpEditorExtension.java <==
/*******************************************************************************
 * Copyright (c) 2003, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.http.internal.junit.editor;

import org.eclipse.hyades.test.common.internal.editor.TestSuiteEditorExtension;
import org.eclipse.hyades.test.http.TestHttpPlugin;
import org.eclipse.hyades.test.ui.editor.form.util.WidgetFactory;
import org.eclipse.hyades.ui.editor.IHyadesEditorPart;

/**
 * @author marcelop
 * @since 1.0.2
 */
public class HttpEditorExtension 
extends TestSuiteEditorExtension
{
	public static final String EXTENSION_ID = "org.eclipse.hyades.test.http.internal.junit.editor.HttpEditorExtension";

	/**
	 * @see org.eclipse.hyades.ui.editor.IEditorExtension#createPages()
	 */
	public void createPages()
	{
		IHyadesEditorPart hyadesEditorPart = getHyadesEditorPart();
		WidgetFactory widgetFactory = new WidgetFactory();
		
		setTestSuiteForm(new HttpForm(this, widgetFactory));
		getTestSuiteForm().setTestCasePageIndex(PAGE_TEST_CASES);
		hyadesEditorPart.addPage(getTestSuiteForm().createControl());
		hyadesEditorPart.setPageText(PAGE_OVERVIEW, TestHttpPlugin.getString("W_OVERVIEW"));

		setTestCasesForm(new HttpTestCasesForm(this, widgetFactory));
		hyadesEditorPart.addPage(getTestCasesForm().createControl());
		hyadesEditorPart.setPageText(PAGE_TEST_CASES, TestHttpPlugin.getString("W_REQUESTS"));
		
		setBehaviorForm(new HttpBehaviorForm(this, widgetFactory));
		hyadesEditorPart.addPage(getBehaviorForm().createControl());
		hyadesEditorPart.setPageText(PAGE_BEHAVIOR, TestHttpPlugin.getString("W_BEHAVIOR"));
		
		getTestSuiteForm().updateTitle();
	}
}
